@@ -21,9 +21,10 @@
  * Author: Alexander Larsson <alexl@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 #include "gdatainputstream.h"
 #include "gioenumtypes.h"
+#include "gioerror.h"
 #include "glibintl.h"
 
 #include "gioalias.h"
@@ -31,7 +32,7 @@
 /**
  * SECTION:gdatainputstream
  * @short_description: Data Input Stream
- * @include: gio.h
+ * @include: gio/gio.h
  * @see_also: #GInputStream
  * 
  * Data input stream implements #GInputStream and includes functions for 
@@ -305,8 +306,8 @@ read_data (GDataInputStream  *stream,
 	return FALSE;
       if (res == 0)
 	{
-	  g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		       _("Unexpected early end-of-stream"));
+	  g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+                               _("Unexpected early end-of-stream"));
 	  return FALSE;
 	}
     }
@@ -329,7 +330,7 @@ read_data (GDataInputStream  *stream,
  * Reads an unsigned 8-bit/1-byte value from @stream.
  *
  * Returns: an unsigned 8-bit/1-byte value read from the @stream or %0 
- * if an error occured.
+ * if an error occurred.
  **/
 guchar
 g_data_input_stream_read_byte (GDataInputStream  *stream,
@@ -359,7 +360,7 @@ g_data_input_stream_read_byte (GDataInputStream  *stream,
  * see g_data_stream_get_byte_order() and g_data_stream_set_byte_order().
  * 
  * Returns: a signed 16-bit/2-byte value read from @stream or %0 if 
- * an error occured.
+ * an error occurred.
  **/
 gint16
 g_data_input_stream_read_int16 (GDataInputStream  *stream,
@@ -403,7 +404,7 @@ g_data_input_stream_read_int16 (GDataInputStream  *stream,
  * see g_data_stream_get_byte_order() and g_data_stream_set_byte_order(). 
  * 
  * Returns: an unsigned 16-bit/2-byte value read from the @stream or %0 if 
- * an error occured. 
+ * an error occurred. 
  **/
 guint16
 g_data_input_stream_read_uint16 (GDataInputStream  *stream,
@@ -451,7 +452,7 @@ g_data_input_stream_read_uint16 (GDataInputStream  *stream,
  * was cancelled, the error %G_IO_ERROR_CANCELLED will be returned. 
  *   
  * Returns: a signed 32-bit/4-byte value read from the @stream or %0 if 
- * an error occured. 
+ * an error occurred. 
  **/
 gint32
 g_data_input_stream_read_int32 (GDataInputStream  *stream,
@@ -499,7 +500,7 @@ g_data_input_stream_read_int32 (GDataInputStream  *stream,
  * was cancelled, the error %G_IO_ERROR_CANCELLED will be returned. 
  * 
  * Returns: an unsigned 32-bit/4-byte value read from the @stream or %0 if 
- * an error occured. 
+ * an error occurred. 
  **/
 guint32
 g_data_input_stream_read_uint32 (GDataInputStream  *stream,
@@ -547,7 +548,7 @@ g_data_input_stream_read_uint32 (GDataInputStream  *stream,
  * was cancelled, the error %G_IO_ERROR_CANCELLED will be returned. 
  * 
  * Returns: a signed 64-bit/8-byte value read from @stream or %0 if 
- * an error occured.  
+ * an error occurred.  
  **/
 gint64
 g_data_input_stream_read_int64 (GDataInputStream  *stream,
@@ -595,7 +596,7 @@ g_data_input_stream_read_int64 (GDataInputStream  *stream,
  * was cancelled, the error %G_IO_ERROR_CANCELLED will be returned. 
  * 
  * Returns: an unsigned 64-bit/8-byte read from @stream or %0 if 
- * an error occured. 
+ * an error occurred. 
  **/
 guint64
 g_data_input_stream_read_uint64 (GDataInputStream  *stream,
@@ -738,7 +739,7 @@ scan_for_newline (GDataInputStream *stream,
  * triggering the cancellable object from another thread. If the operation
  * was cancelled, the error %G_IO_ERROR_CANCELLED will be returned. 
  * 
- * Returns: a string with the line that was read in (including the newlines).
+ * Returns: a string with the line that was read in (without the newlines).
  * Set @length to a #gsize to get the length of the read line. Returns %NULL on an error.
  **/
 char *
