@@ -1303,14 +1303,17 @@ parse_long_option (GOptionContext *context,
 	  strcmp (arg, group->entries[j].long_name) == 0)
 	{
 	  gchar *option_name;
+	  gboolean retval;
 
 	  option_name = g_strconcat ("--", group->entries[j].long_name, NULL);
-	  parse_arg (context, group, &group->entries[j],
-		     NULL, option_name, error);
+	  retval = parse_arg (context, group, &group->entries[j],
+			      NULL, option_name, error);
 	  g_free(option_name);
 	  
 	  add_pending_null (context, &((*argv)[*index]), NULL);
 	  *parsed = TRUE;
+
+	  return retval;
 	}
       else
 	{
